@@ -70,14 +70,15 @@ public interface CKanPublisherService extends RemoteService {
 
 	/**
 	 * Retrieve the list of groups the user can choose to associate this product with.
+	 * @param orgName retrieve the groups in the context linked to this name. If null, returns
+	 * the one in the current context.
 	 * @return a list of groups' beans
 	 */
-	List<GroupBean> getUserGroups();
-
-	//	/**
-	//	 * Return a tree object representing the whole folder hierarchy
-	//	 * @param folderId
-	//	 * @return ResourceElementBean
-	//	 */
-	//	ResourceElementBean getTreeFolder(String folderId);
+	List<GroupBean> getUserGroups(String orgName);
+	
+	/**
+	 * The method checks if the user is a publisher or he/she doesn't have the rights to publish
+	 * @return true if he/she can publish, false otherwise
+	 */
+	boolean isPublisherUser(boolean isWorkspaceRequest);
 }
